@@ -20,6 +20,10 @@
 #ifndef DAEMONREGISTRY_H
 #define DAEMONREGISTRY_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <tqstring.h>
 
 #include <tdelocale.h>
@@ -46,8 +50,10 @@ struct DaemonRegistryEntry
 
 DaemonRegistryEntry DaemonRegistry[] =
 {
-    { "Nettools", NetToolsBackend::createInstance },
     { "Sys", SysBackend::createInstance },
+#if defined( WITH_NETTOOLS )
+    { "Nettools", NetToolsBackend::createInstance },
+#endif
     { TQString(), 0 }
 };
 
