@@ -37,7 +37,7 @@ class Interface;
 
 class InterfaceMonitor : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
